@@ -1,23 +1,22 @@
 """
 Tests for the autoregressive transforms.
-Code taken from https://github.com/bayesiains/nsf
+Code partially taken from https://github.com/bayesiains/nsf
 """
 
 import torch
 import unittest
 
 from normflows.flows.neural_spline import autoregressive
-from normflows.flows.neural_spline.flow_test import FlowTest
+from normflows.flows.flow_test import FlowTest
 
 
 class MaskedPiecewiseRationalQuadraticAutoregressiveFlowTest(FlowTest):
-    def test_forward_inverse_are_consistent(self):
-        batch_size = 10
-        features = 20
+    def test_mprqas(self):
+        batch_size = 5
+        features = 10
         inputs = torch.rand(batch_size, features)
-        self.eps = 1e-3
 
-        transform = autoregressive.MaskedPiecewiseRationalQuadraticAutoregressive(
+        flow = autoregressive.MaskedPiecewiseRationalQuadraticAutoregressive(
             num_bins=10,
             features=features,
             hidden_features=30,
@@ -25,7 +24,7 @@ class MaskedPiecewiseRationalQuadraticAutoregressiveFlowTest(FlowTest):
             use_residual_blocks=True,
         )
 
-        self.assert_forward_inverse_are_consistent(transform, inputs)
+        self.checkForwardInverse(flow, inputs)
 
 
 if __name__ == "__main__":
