@@ -2,10 +2,11 @@ from ..nets.lipschitz import InducedNormLinear, InducedNormConv2d
 
 
 def set_requires_grad(module, flag):
-    """
-    Sets requires_grad flag of all parameters of a torch.nn.module
-    :param module: torch.nn.module
-    :param flag: Flag to set requires_grad to
+    """Sets requires_grad flag of all parameters of a torch.nn.module
+
+    Args:
+      module: torch.nn.module
+      flag: Flag to set requires_grad to
     """
 
     for param in module.parameters():
@@ -13,10 +14,12 @@ def set_requires_grad(module, flag):
 
 
 def clear_grad(model):
-    """
-    Set gradients of model parameter to None as this speeds up training,
-    see https://www.youtube.com/watch?v=9mS1fIYj1So
-    :param model: Model to clear gradients of
+    """Set gradients of model parameter to None as this speeds up training,
+
+    See [youtube](https://www.youtube.com/watch?v=9mS1fIYj1So)
+
+    Args:
+      model: Model to clear gradients of
     """
     for param in model.parameters():
         param.grad = None
